==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DTCMacOS;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Settings for third-party signal providers (based on the &#x60;MACOS&#x60; platform)
 */
@ApiModel(description = "Settings for third-party signal providers (based on the `MACOS` platform)")
@JsonPropertyOrder({ DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders.JSON_PROPERTY_DTC })
@JsonTypeName("DeviceAssuranceMacOSPlatform_allOf_thirdPartySignalProviders")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DTC = "dtc";
    private DTCMacOS dtc;

    public DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders() {
    }

    public DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders dtc(DTCMacOS dtc) {

        this.dtc = dtc;
        return this;
    }

    /**
     * Get dtc
     *
     * @return dtc
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DTC)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DTCMacOS getDtc() {
        return dtc;
    }

    @JsonProperty(JSON_PROPERTY_DTC)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDtc(DTCMacOS dtc) {
        this.dtc = dtc;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders deviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders = (DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders) o;
        return Objects.equals(this.dtc, deviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders.dtc);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(dtc);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders {\n");
        sb.append("    dtc: ").append(toIndentedString(dtc)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DTCMacOS;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Settings for third-party signal providers (based on the &#x60;MACOS&#x60; platform)
 */
@ApiModel(description = "Settings for third-party signal providers (based on the `MACOS` platform)")
@JsonPropertyOrder({ DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders.JSON_PROPERTY_DTC })
@JsonTypeName("DeviceAssuranceMacOSPlatform_allOf_thirdPartySignalProviders")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DTC = "dtc";
    private DTCMacOS dtc;

    public DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders() {
    }

    public DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders dtc(DTCMacOS dtc) {

        this.dtc = dtc;
        return this;
    }

    /**
     * Get dtc
     *
     * @return dtc
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DTC)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DTCMacOS getDtc() {
        return dtc;
    }

    @JsonProperty(JSON_PROPERTY_DTC)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDtc(DTCMacOS dtc) {
        this.dtc = dtc;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders deviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders = (DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders) o;
        return Objects.equals(this.dtc, deviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders.dtc);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(dtc);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceMacOSPlatformAllOfThirdPartySignalProviders {\n");
        sb.append("    dtc: ").append(toIndentedString(dtc)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
